
.. _`WBEM operation statistics`:

WBEM operation statistics
-------------------------

.. automodule:: pywbem._statistics

.. autoclass:: pywbem.Statistics
   :members:

.. autoclass:: pywbem.OperationStatistic
   :members:
